@@ -107,13 +107,6 @@ class OOF(object):
 
     def predict(self, X):
 
-        # preds = []
-        # for estimator in self._estimators:
-        #     _ = self._predict(estimator)(X)
-        #     preds.append(_)
-        #
-        # return np.array(preds).mean(0)
-
         func = lambda e: self._predict(e)(X)
         return np.array(list(map(func, self._estimators))).mean(0)
 
@@ -157,9 +150,9 @@ class OOF(object):
             self.feature_importances_[n_fold] = get_imp(self._estimators[-1], X_train, self._importance_type)
 
             if feval is not None:
-                if self.oof_test_proba.shape[1] == 2:  # todo: 目前不支持多分类
+                if self.oof_test_proba.shape[-1] == 2:  # todo: 目前不支持多分类
                     valid_metrics.append(feval(y_valid, valid_predict[:, 1]))  # 二分类
-                else:
+                elif self.oof_test_proba.ndim == 1:
                     valid_metrics.append(feval(y_valid, valid_predict))  # 回归
 
         if self.oof_test_proba.shape[1] == 2:
@@ -189,8 +182,8 @@ class OOF(object):
         scores = []
         for cv in tqdm(cv_list, desc='opt cv 🐢'):  # range(3, 16):
             oof = cls(params)
-            oof.fit(X, y, X_test, **run_kwargs)
-            scores.append((oof.oof_score, cv, oof))
+            _ = oof.fit(X, y, X_test, **run_kwargs)
+            scores.append((_, cv, oof))
 
         return sorted(scores)[::-1]
 
